;-----------------------------------------------------------------------------
;Filename : TPS_HY17P58.asm
;-----------------------------------------------------------------------------
; Copyright 2019 Hycon Technology, Corp.
; http://www.hycontek.com/
;
; Release 1.0
;     2019/09/9
;
; Program Description:
;--------------------
;
; HY17P58
; ---------
;          |
; INP<--TPS|
; INN<--TPS|
;          |
;     GND  |
;          |
; ---------
;
;-----------------------------------------------------------------------------

;----------------------------------------------------------------------------
; Definitions
;----------------------------------------------------------------------------
DEFINE  ICE=1      ;ICE=1  Body=0
temperature	EQU		1900H  ;25*256=1900H
;----------------------------------------------------------------------------
; Includes
;----------------------------------------------------------------------------
Include		HY17P58.inc
;----------------------------------------------------------------------------
; Global CONSTANTS
;----------------------------------------------------------------------------
ADCchannel    EQU  0F0H
TPSADCL       EQU  0F1H  ;TPS Output Data
TPSADCM       EQU  0F2H
TPSADCH       EQU  0F3H
TPSADCPL      EQU  0F4H  ;TPS- RAW Data
TPSADCPM      EQU  0F5H
TPSADCPH      EQU  0F6H
TPSADCNL      EQU  0F7H  ;TPS+ RAW Data
TPSADCNM      EQU  0F8H
TPSADCNH      EQU  0F9H

;-----------------------------------------------------------------------------
; Reset And Interrupt Vector Table
;-----------------------------------------------------------------------------
  ORG   0000H ;Reset Vector
  JMP   ProBegin
;
;;-----------------------------------------------------------------------------
;; Start Program Code
;;-----------------------------------------------------------------------------
ProBegin:
IF  ICE==1
  CALL  TPS_ProBegin
ENDIF
Main:
  NOP
  MVL	3AH
  MVF	BIEARL,F,A
  CLRF	BIEARH,A
  BSF	BIECN,BIERD,A
  MVFF	BIEDRH,80H
  MVFF	BIEDRL,81H
  BSF	BIECN,BIERD,A
  MVFF	BIEDRH,82H
  MVFF	BIEDRL,83H
  BSF	BIECN,BIERD,A
  MVFF	BIEDRH,84H
  MVFF	BIEDRL,85H  
 loop: 
  JMP   loop

ORG   1F00H ;
;-----------------------------------------------------------------------------
; TPS Start Program Code
;-----------------------------------------------------------------------------
TPS_ProBegin:
  CALL  TPS_Start

  BCF   AD1CN0,ENAD1     ;NJeADC TO|첧`ADC
IF  ICE==1
lbsr 1
  MVL	88H
  MVF	LCDCN1,F,B
  SETF  LCDCN3,B
  BSF	BIECN,2,A
ENDIF  
  BSF   BIECN,ENBVD,ACCE
WaitVPPHV:
  BTSS  BIECN,VPPHV,ACCE
  JMP   WaitVPPHV

  MVL   03CH
  MVF   BIEARL,F,A
  BSF   BIECN,BIERD      ;TOVDD>2.6V
  NOP                    ;NJANOPTOCPUॿ`
  MVL   0FFH
  CPSE  BIEDRH,ACCE
  JMP   WriteBIE_END

  MVL   03AH ;03BH
  MVF   BIEARL,F,ACCE
IF  ICE==1
  MVL	Low temperature
ELSE  
  MVL   0FFH
ENDIF  
  MVF   BIEDRL,F,ACCE
IF  ICE==1
  MVL	High temperature
ELSE  
  MVL   0FFH
ENDIF
  MVF   BIEDRH,F,ACCE
  BSF   BIECN,BIEWR      ;TOVDD>2.6V  VPP>8.5V
WaitBIEWR0:
  NOP                    ;NJANOPTOCPUॿ`
  BTSZ  BIECN,BIEWR,ACCE
  JMP   WaitBIEWR0

  MVFF  TPSADCL,BIEDRL
  MVFF  TPSADCM,BIEDRH
  BSF   BIECN,BIEWR      ;TOVDD>2.6V  VPP>8.5V
WaitBIEWR1:
  NOP                    ;NJANOPTOCPUॿ`
  BTSZ  BIECN,BIEWR,ACCE
  JMP   WaitBIEWR1

  MVFF  TPSADCH,BIEDRL
  CLRF  BIEDRH,ACCE
  BSF   BIECN,BIEWR      ;TOVDD>2.6V  VPP>8.5V
WaitBIEWR2:
  NOP                    ;NJANOPTOCPUॿ`
  BTSZ  BIECN,BIEWR,ACCE
  JMP   WaitBIEWR2

  
  
WriteBIE_END:
IF  ICE==1
	ret
ENDIF
  NOP
  JMP   WriteBIE_END

;-----------------------------------------------------------------------------
; Subroutine
;-----------------------------------------------------------------------------
TPS_Start:
  BCF   INTE0,GIE        ;NJeȥ_
 ;==========Setup VDDA=======================================
  MVL   82H
  MVF   PWRCN,F,A

 ;==========Setup Clock======================================

  MVL   01H
  MVF   OSCCN0,F,A
  MVL   00H
  MVF	OSCCN1,F,A
  MVL   01H
  MVF   OSCCN2,F,A

 ;==========Setup ADC========================================
  MVL   87H
  MVF   AD1CN0,F,A
  MVL   03H
  MVF   AD1CN1,F,A
  MVL   0
  MVF   AD1CN2,F,A
  MVL   22H
  MVF   AD1CN3,F,A
  MVL   40H
  MVF   AD1CN4,F,A
  MVL   0B2H
  MVF   AD1CN5,F,A

GetTPS0:
  BSF   AD1CN0,CMFR,ACCE
TPS_Loop0:
  NOP
 ;-- ADC Interrupt Service Routine
  BTSS  INTF0,ADIF,ACCE
  JMP   TPS_Loop0

  ;ADC Data Save to Buffer
  MVFF  AD1L,TPSADCPL
  MVFF  AD1M,TPSADCPM
  MVFF  AD1H,TPSADCPH

  MVL   33H
  MVF   AD1CN3,F,A
  BCF   INTF0,ADIF,ACCE  ;Clear ADC Interrupt Flag
  BSF   AD1CN0,CMFR,ACCE
GetTPS0_END:

GetTPS1:
  BSF   AD1CN0,CMFR,ACCE
TPS_Loop1:
  NOP
 ;-- ADC Interrupt Service Routine
  BTSS  INTF0,ADIF,ACCE
  JMP   TPS_Loop1
  ;ADC Data Save to Buffer
  MVFF  AD1L,TPSADCNL
  MVFF  AD1M,TPSADCNM
  MVFF  AD1H,TPSADCNH

  ;(TPS+)-(TPS-) Data
  MVF   TPSADCNL,W,ACCE
  SUBF  TPSADCPL,W,ACCE
  MVF   TPSADCL,F,ACCE

  MVF   TPSADCNM,W,ACCE
  SUBC  TPSADCPM,W,ACCE
  MVF   TPSADCM,F,ACCE

  MVF   TPSADCNH,W,ACCE
  SUBC  TPSADCPH,W,ACCE
  MVF   TPSADCH,F,ACCE
GetTPS1_END:
  RETI  S

;-----------------------------------------------------------------------------
; End Of File
;-----------------------------------------------------------------------------
  END
